@@ -143,6 +143,14 @@ class LuaScripts(object):
             end
 
             local function update_profile_prop (p_key, v_key, obj, field_type)
+                if obj.update_condition then
+                    if not (redis.call('EXISTS', obj.update_condition) == 1) then
+                        return
+                    else
+                        redis.call('DEL', obj.update_condition)
+                    end
+                end
+            
                 local current_value = redis.call('HGET', p_key, v_key)
                 local v = obj["value"]
                 if field_type == 'counter' then
