@@ -527,7 +527,11 @@ class Profile(object):
                 continue
             data_type, profile_property = cls.property_by_prefix[prefix]
             props = properties.get(data_type, {})
-            value = data[data_type_name + profile_properties.PROFILE_VALUE_POSTFIX]
+            try:
+                value = data[data_type_name + profile_properties.PROFILE_VALUE_POSTFIX]
+            except KeyError as e:
+                print(data)
+                raise e
             updated = cls.timestamp_to_datetime(data.get(
                 data_type_name + profile_properties.PROFILE_VALUE_UPDATED_POSTFIX))
             created = cls.timestamp_to_datetime(data.get(
